<?php
/*
Description: Plugin settings page for Gift Offer.
Version: 1.1.0
Author: GR-Media
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Ajouter un lien vers les réglages du plugin dans le menu WooCommerce
add_filter('woocommerce_settings_tabs_array', 'add_gift_offer_settings_tab', 50);

function add_gift_offer_settings_tab($tabs) {
    $tabs['gift_offer_settings'] = __('Free Gift Offer', 'woocommerce');
    return $tabs;
}

// Afficher le contenu de la page des réglages du plugin
add_action('woocommerce_settings_tabs_gift_offer_settings', 'gift_offer_settings_tab_content');

function gift_offer_settings_tab_content() {
    woocommerce_admin_fields(get_gift_offer_settings());
}

// Définir les champs de réglages du plugin
function get_gift_offer_settings() {
    $settings = array(
        'section_title' => array(
            'name'     => __('Free Gift Offer Settings', 'woocommerce'),
            'type'     => 'title',
            'desc'     => '',
            'id'       => 'gift_offer_settings_section_title'
        ),
        'minimum_amount' => array(
            'name' => __('Minimum Amount', 'woocommerce'),
            'type' => 'number',
            'desc' => __('Enter the minimum cart amount to qualify for the free gift.', 'woocommerce'),
            'id'   => 'gift_offer_minimum_amount',
            'css'  => 'width:100px;',
            'std'  => '50',
            'desc_tip' => true,
        ),
        'gift_product_id' => array(
            'name' => __('Gift Product ID', 'woocommerce'),
            'type' => 'number',
            'desc' => __('Enter the product ID of the gift product.', 'woocommerce'),
            'id'   => 'gift_offer_gift_product_id',
            'css'  => 'width:100px;',
            'std'  => '54',
            'desc_tip' => true,
        ),
        'replacement_text' => array(
            'name' => __('Replacement Text', 'woocommerce'),
            'type' => 'text',
            'desc' => __('Enter the replacement text to be displayed for the gift product subtotal.', 'woocommerce'),
            'id'   => 'gift_offer_replacement_text',
            'css'  => 'width:300px;',
            'std'  => 'Cadeau',
            'desc_tip' => true,
        ),
        'start_datetime' => array(
            'name' => __('Start Date and Time', 'woocommerce'),
            'type' => 'datetime-local',
            'desc' => __('Enter the start date and time for the gift offer.', 'woocommerce'),
            'id'   => 'gift_offer_start_datetime',
            'desc_tip' => true,
        ),
        'end_datetime' => array(
            'name' => __('End Date and Time', 'woocommerce'),
            'type' => 'datetime-local',
            'desc' => __('Enter the end date and time for the gift offer.', 'woocommerce'),
            'id'   => 'gift_offer_end_datetime',
            'desc_tip' => true,
        ),
        'section_end' => array(
            'type' => 'sectionend',
            'id' => 'gift_offer_settings_section_end'
        )
    );

    return apply_filters('gift_offer_settings', $settings);
}

// Sauvegarder les réglages lorsque le formulaire est soumis
add_action('woocommerce_update_options_gift_offer_settings', 'update_gift_offer_settings');

function update_gift_offer_settings() {
    woocommerce_update_options(get_gift_offer_settings());
}
?>
