<?php

/**
 * Plugin name: Gift Offer
 * Plugin URI: https://gr-media.ch/index.php/gift-offer/
 * Description: Offer gifts to your customers
 * Author: gr-media
 * Author URI: https://www.gr-media.ch
 * Version: 1.1.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

$gift_product_id = get_option('gift_offer_gift_product_id');
$replacement_text = get_option('gift_offer_replacement_text');
$minimum_amount = get_option('gift_offer_minimum_amount');

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {

    require_once(plugin_dir_path(__FILE__) . 'gift-offer-settings.php');

    // Récupérer les valeurs des champs de date et heure
    $start_datetime = get_option('gift_offer_start_datetime');
    $end_datetime = get_option('gift_offer_end_datetime');

    // Convertir les valeurs en timestamps
    $start_timestamp = strtotime($start_datetime);
    $end_timestamp = strtotime($end_datetime);

    // Vérifier si l'offre est dans la période active
    $current_timestamp = current_time('timestamp');
    if ($current_timestamp >= $start_timestamp && $current_timestamp <= $end_timestamp) {

        // Vérifier et agir sur le contenu du panier
        add_action('woocommerce_before_calculate_totals', 'check_and_add_gift', 10, 1);

        function check_and_add_gift($cart) {
            global $gift_product_id, $replacement_text, $minimum_amount, $end_timestamp;

            // Vérification de l'heure de fin
            $current_timestamp = current_time('timestamp');
            if ($current_timestamp > $end_timestamp) {
                // Heure de fin atteinte, retirer le produit offert du panier
                foreach ($cart->get_cart() as $cart_item_key => $cart_item) {
                    if ($cart_item['product_id'] == $gift_product_id) {
                        $cart->remove_cart_item($cart_item_key);
                        break;
                    }
                }
                return; // Rien d'autre à faire
            }

            // Calculer le sous-total du panier sans le produit offert
            $subtotal_without_gift = 0;
            foreach ($cart->get_cart() as $cart_item_key => $cart_item) {
                if (isset($cart_item['line_total']) && $cart_item['product_id'] != $gift_product_id) {
                    $subtotal_without_gift += $cart_item['line_total'];
                }
            }

            if ($subtotal_without_gift >= $minimum_amount) {
                // Vérifier si le produit offert n'est pas déjà dans le panier
                $gift_in_cart = false;
                foreach ($cart->get_cart() as $cart_item) {
                    if ($cart_item['product_id'] == $gift_product_id) {
                        $gift_in_cart = true;
                        break;
                    }
                }

                if (!$gift_in_cart) {
                    // Ajouter le produit offert au panier
                    $cart->add_to_cart($gift_product_id, 1);
                }
            } else {
                // Retirer le produit offert si le montant minimum n'est pas atteint
                foreach ($cart->get_cart() as $cart_item_key => $cart_item) {
                    if ($cart_item['product_id'] == $gift_product_id) {
                        $cart->remove_cart_item($cart_item_key);
                        break;
                    }
                }
            }
        }

        // Empêcher la modification de la quantité du produit offert dans le panier
        add_filter('woocommerce_cart_item_quantity', 'disable_gift_quantity_change', 10, 3);

        function disable_gift_quantity_change($product_quantity, $cart_item_key, $cart_item) {
            global $gift_product_id;
            if ($cart_item['product_id'] == $gift_product_id) {
                return 1; // Empêcher la modification de la quantité du produit offert
            }
            return $product_quantity;
        }

        // Empêcher le retrait manuel du produit offert du panier
        add_filter('woocommerce_cart_item_remove_link', 'prevent_gift_removal_from_cart', 10, 2);

        function prevent_gift_removal_from_cart($link, $cart_item_key) {
            global $gift_product_id;
            $cart_item = WC()->cart->get_cart()[$cart_item_key];

            if ($cart_item['product_id'] == $gift_product_id) {
                $link = '';
            }

            return $link;
        }

        // Afficher le prix du produit offert dans la colonne "Prix"
        add_filter('woocommerce_cart_item_price', 'display_gift_price_in_column', 10, 3);

        function display_gift_price_in_column($product_price, $cart_item, $cart_item_key) {
            global $gift_product_id;
            if ($cart_item['product_id'] == $gift_product_id) {
                return wc_price(wc_get_product($gift_product_id)->get_price());
            }
            return $product_price;
        }

        // Remplacer le sous-total du produit offert par le texte de remplacement dans la colonne "Sous-total"
        add_filter('woocommerce_cart_item_subtotal', 'replace_gift_subtotal_with_text', 10, 3);

        function replace_gift_subtotal_with_text($product_subtotal, $cart_item, $cart_item_key) {
            global $gift_product_id, $replacement_text;
            if ($cart_item['product_id'] == $gift_product_id) {
                return $replacement_text;
            }
            return $product_subtotal;
        }

        // Mettre à jour le sous-total du panier pour exclure le prix du produit offert
        add_filter('woocommerce_cart_subtotal', 'update_cart_subtotal', 10, 3);

        function update_cart_subtotal($subtotal_html, $compound, $cart) {
            global $gift_product_id, $replacement_text, $minimum_amount;

            $subtotal_without_gift = 0;
            $gift_subtotal_found = false;

            foreach ($cart->get_cart() as $cart_item_key => $cart_item) {
                $product = $cart_item['data'];
                if ($product->get_id() != $gift_product_id) {
                    $subtotal_without_gift += $cart_item['line_total'];
                } else {
                    $gift_subtotal_found = true;
                }
            }

            if ($cart->get_cart_contents_total() >= $minimum_amount && $cart->has_discount($gift_product_id) && $gift_subtotal_found) {
                $subtotal_html = wc_price(0) . ' ' . $replacement_text;
            } else {
                $subtotal_html = wc_price($subtotal_without_gift);
            }

            return $subtotal_html;
        }

        // Recalculer le total du panier en excluant le prix du produit offert
        add_filter('woocommerce_calculated_total', 'recalculate_total_excluding_gift', 10, 2);

        function recalculate_total_excluding_gift($total, $cart) {
            global $gift_product_id;

            $subtotal_without_gift = 0;
            foreach ($cart->get_cart() as $cart_item) {
                if ($cart_item['product_id'] != $gift_product_id) {
                    $subtotal_without_gift += $cart_item['line_total'];
                }
            }

            return $subtotal_without_gift + $cart->shipping_total + $cart->tax_total;
        }

        // Utiliser le nom du produit original pour le produit offert
        add_filter('woocommerce_cart_item_name', 'restore_gift_product_name', 10, 3);

        function restore_gift_product_name($product_name, $cart_item, $cart_item_key) {
            global $gift_product_id;
            if ($cart_item['product_id'] == $gift_product_id) {
                $product = wc_get_product($gift_product_id);
                $product_name = $product->get_name();
            }
            return $product_name;
        }

    } // Fin de la vérification de la période active

} // Fin de la vérification de WooCommerce
?>
